@@ -2,7 +2,7 @@
 # This file is part of pygal
 #
 # A python svg graph plotting library
-# Copyright © 2012-2014 Kozea
+# Copyright © 2012-2025 Kozea
 #
 # This library is free software: you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -16,21 +16,18 @@
 #
 # You should have received a copy of the GNU Lesser General Public License
 # along with pygal. If not, see <http://www.gnu.org/licenses/>.
-"""
-Horizontal bar graph
+"""Horizontal bar graph"""
 
-"""
-from pygal.graph.horizontal import HorizontalGraph
 from pygal.graph.bar import Bar
+from pygal.graph.horizontal import HorizontalGraph
 
 
 class HorizontalBar(HorizontalGraph, Bar):
     """Horizontal Bar graph"""
 
     def _plot(self):
-        for index, serie in enumerate(self.series[::-1]):
-            num = len(self.series) - index - 1
-            self.bar(self._serie(num), serie, index)
-        for index, serie in enumerate(self.secondary_series[::-1]):
-            num = len(self.secondary_series) + len(self.series) - index - 1
-            self.bar(self._serie(num), serie, index + len(self.series), True)
+        """Draw the bars in reverse order"""
+        for serie in self.series[::-1]:
+            self.bar(serie)
+        for serie in self.secondary_series[::-1]:
+            self.bar(serie, True)
